@@ -125,7 +125,7 @@ def project_deploy(
     docker_image_registry: Optional[str] = None,
     docker_image_repository: Optional[str] = None,
     profile: Optional[str] = None,
-    deployment_mode: Optional[DeploymentMode] = None,
+    deployment_mode: Optional[str] = None,
     ververica_url: Optional[str] = None,
     ververica_namespace: Optional[str] = None,
     ververica_deployment_target_name: Optional[str] = None,
@@ -138,7 +138,7 @@ def project_deploy(
         docker_registry_url=docker_image_registry,
         docker_image_repository=docker_image_repository,
         profile=profile,
-        deployment_mode=deployment_mode,
+        deployment_mode=DeploymentMode.from_label(deployment_mode),
         ververica_url=ververica_url,
         ververica_namespace=ververica_namespace,
         ververica_deployment_target_name=ververica_deployment_target_name,
